@@ -1,4 +1,3 @@
-import os
 import requests
 import uuid
 from argparse import ArgumentParser
@@ -19,30 +18,16 @@ context = NetworkContext()
 
 class Client:
     wallet: Wallet
-    # dict type-checking compatible only with python > 3.8:
-    # contacts: dict[str, PubKey]
 
     def __init__(self, load_from_file=True):
         self.wallet = Wallet()
-        self.contacts = self.load_contacts()
-
-    def load_contacts(self):
-        # load public keys from file in known_nodes/ and return a dict {hash_pk: PubKey}
-        contact_name_to_pk = {}
-        for filepath in os.listdir("./known_nodes"):
-            absolute_filepath = f"{os.getcwd()}/known_nodes/{filepath}"
-            name, pk = filepath.split(".")[0], Wallet.load_pub_key(absolute_filepath)
-            contact_name_to_pk[name] = pk
-        return contact_name_to_pk
 
     def send_transaction(self, receiver: str, amount: float, fees: float):
         print(f"Sending {amount} to {receiver} with fees {fees}")
-        if receiver not in self.contacts:
-            raise Exception(f"Not in contacts list: {receiver}")
         tx = Transaction(
             uuid=str(uuid.uuid4()),
             sender=self.wallet.get_public_key(),
-            receiver=self.contacts[receiver],
+            receiver=receiver,
             amount=float(amount),
             fees=float(fees),
         )
