@@ -50,18 +50,16 @@ class PubKey:
 class Transaction:
     uuid: str
     sender: PubKey
-    receiver: PubKey
+    receiver: str
     amount: float
     fees: float = 0
     status: int = SUCCESS  # REVERTED when insufficient funds
 
     def hash(self):
-        if self.sender.rsa_pub_key == MINING_REWARD_ADDRESS:
-            return MINING_REWARD_ADDRESS
         hasher = hashlib.sha256()
         hasher.update(self.uuid.encode())
         hasher.update(self.sender.dump())
-        hasher.update(self.receiver.dump())
+        hasher.update(self.receiver.encode())
         hasher.update(str(self.amount).encode())
         hasher.update(str(self.fees).encode())
         return hasher.hexdigest()
@@ -85,7 +83,7 @@ class Transaction:
         )
 
     def __repr__(self) -> str:
-        return f"Transaction({str(self)})"
+        return f"Transaction({self.html()})"
 
 
 @dataclass
